import { Controller, Get, Post, Body, HttpCode, UseGuards, HttpStatus, UseInterceptors, UploadedFiles } from '@nestjs/common';
import { FileFieldsInterceptor } from '@nestjs/platform-express';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { getMulterConfig } from 'src/core/multer.config';
import { Constants } from 'src/utils/constants';
import { FooterCmsService } from './footer-cms.service';
import { UpdateFooterCmsDto } from './dto/update-footer-cms.dto';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';

@Controller({ path: 'footer-cms', version: Constants.API_VERSION_1 })

export class FooterCmsController {
    constructor(private readonly service: FooterCmsService) { }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: 'logo', maxCount: 1 },
            { name: 'paymentMethodImage', maxCount: 1 },
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateFooterCmsDto,
        @UploadedFiles() files: { 
            logo: UploadedMulterFileI,
            paymentMethodImage: UploadedMulterFileI,
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
