import { Controller, Get, Post, Body, HttpCode, UseGuards, HttpStatus, UseInterceptors, UploadedFiles } from '@nestjs/common';
import { FileFieldsInterceptor } from '@nestjs/platform-express';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { getMulterConfig } from 'src/core/multer.config';
import { Constants } from 'src/utils/constants';
import { HomePageSectionSevenCmsService } from './home-page-section-seven-cms.service';
import { UpdateHomePageSectionSevenCmsDto } from './dto/update-home-page-section-seven-cms.dto';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';

@Controller({ path: 'home-page-sec-seven-cms', version: Constants.API_VERSION_1 })

export class HomePageSectionSevenCmsController {
    constructor(private readonly service: HomePageSectionSevenCmsService) { }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: 'backgroundImage', maxCount: 1 },
            { name: 'productImage', maxCount: 1 },
            { name: 'productTwoImage', maxCount: 1 },
            { name: 'productThreeImage', maxCount: 1 },
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateHomePageSectionSevenCmsDto,
        @UploadedFiles() files: { 
            backgroundImage: UploadedMulterFileI,
            productImage: UploadedMulterFileI,
            productTwoImage: UploadedMulterFileI,
            productThreeImage: UploadedMulterFileI,
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
