import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { FileUploadsService } from 'src/modules/file-uploads/file-uploads.service';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { HomePageSectionSevenCmsRepository } from './home-page-section-seven-cms.repository';
import { UpdateHomePageSectionSevenCmsDto } from './dto/update-home-page-section-seven-cms.dto';
import { HomePageSectionSevenCms } from './entities/home-page-section-seven-cms.entity';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';

@Injectable()
export class HomePageSectionSevenCmsService {
    constructor(
        @InjectRepository(HomePageSectionSevenCmsRepository)
        private readonly repository: HomePageSectionSevenCmsRepository,
        private readonly fileService: FileUploadsService,
        private readonly doSpaceService: DoSpacesService
    ) { }

    async updateOrCreateData(
        dto: UpdateHomePageSectionSevenCmsDto,
        files: {
            backgroundImage: UploadedMulterFileI,
            productImage: UploadedMulterFileI,
            productTwoImage: UploadedMulterFileI,
            productThreeImage: UploadedMulterFileI,
        }
    ): Promise<HomePageSectionSevenCms | Error> {
        // process image one
        if (files && files.backgroundImage) {
            const backgroundImage: any = await this.doSpaceService.uploadFile(files.backgroundImage[0], 'HomePageSectionSevenCms/');
            dto.backgroundImage = backgroundImage;
        }

        // process image two
        if (files && files.productImage) {
            const productImage: any = await this.doSpaceService.uploadFile(files.productImage[0], 'HomePageSectionSevenCms/');
            dto.productImage = productImage;
        }
        // process image two
        if (files && files.productTwoImage) {
            const productTwoImage: any = await this.doSpaceService.uploadFile(files.productTwoImage[0], 'HomePageSectionSevenCms/');
            dto.productTwoImage = productTwoImage;
        }
        // process image two
        if (files && files.productThreeImage) {
            const productThreeImage: any = await this.doSpaceService.uploadFile(files.productThreeImage[0], 'HomePageSectionSevenCms/');
            dto.productThreeImage = productThreeImage;
        }

        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        }
        else {
            let id = isExists[0].id;
            const data = await this.repository.UpdateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<HomePageSectionSevenCms[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Home page section Seven cms data fetched successfully", "data", data);
    }
}
