import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { FileUploadsService } from 'src/modules/file-uploads/file-uploads.service';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { HomePageSectionSixCmsRepository } from './home-page-section-six-cms.repository';
import { UpdateHomePageSectionSixCmsDto } from './dto/update-home-page-section-six-cms.dto';
import { HomePageSectionSixCms } from './entities/home-page-section-six-cms.entity';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';

@Injectable()
export class HomePageSectionSixCmsService {
    constructor(
        @InjectRepository(HomePageSectionSixCmsRepository)
        private readonly repository: HomePageSectionSixCmsRepository,
        private readonly fileService: FileUploadsService,
        private readonly doSpaceService: DoSpacesService
    ) { }

    async updateOrCreateData(
        dto: UpdateHomePageSectionSixCmsDto,
        files: {
            image: UploadedMulterFileI,
        }
    ): Promise<HomePageSectionSixCms | Error> {
        // process image one
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], 'HomePageSectionSixCms/');
            dto.image = image;
        }

        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        }
        else {
            let id = isExists[0].id;
            const data = await this.repository.UpdateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<HomePageSectionSixCms[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Home page section Six cms data fetched successfully", "data", data);
    }
}
