import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateContactAddressDto } from "./dto/create-contact-address.dto";
import { UpdateContactAddressDto } from "./dto/update-contact-address.dto";
import { ContactAddress } from "./entities/contact-address.entity";

@EntityRepository(ContactAddress)
export class ContactAddressRepository extends Repository<ContactAddress> {
    async createEntity(dto: CreateContactAddressDto): Promise<ContactAddress | Error> {
        try {
            const { title, address, email, phone } = dto;
            const entity = this.create({
                title,
                address,
                email,
                phone
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ContactAddress | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateContactAddressDto): Promise<ContactAddress | Error> {
        try {
            await this.update(id, {
                title : dto.title,
                address : dto.address,
                email : dto.email,
                phone : dto.phone
            });
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query : any): Promise<ContactAddress[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ContactAddress)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if(updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch(e) {
            return e;
        }
    }
}