import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateCustomerReviewDto } from "./dto/create-customer-review.dto";
import { UpdateCustomerReviewDto } from "./dto/update-customer-review.dto";
import { CustomerReview } from "./entities/customer-review.entity";

@EntityRepository(CustomerReview)
export class CustomerReviewRepository extends Repository<CustomerReview> {
    async createEntity(dto: CreateCustomerReviewDto): Promise<CustomerReview | Error> {
        try {
            const { message, reviewerName, reviewerImage } = dto;
            const entity = this.create({
                message,
                reviewerName,
                reviewerImage
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<CustomerReview | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateCustomerReviewDto): Promise<CustomerReview | Error> {
        try {
            await this.update(id, {
                message : dto.message,
                reviewerName : dto.reviewerName,
                reviewerImage : dto.reviewerImage
            });
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query : any): Promise<CustomerReview[] | Error> {
        try {
            return await this.find({
                where: { 
                    ...query, 
                    isDeleted: false 
                }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(CustomerReview)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if(updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch(e) {
            return e;
        }
    }
}