import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { HomeSliderRepository } from './home-slider.repository';
import { CreateHomeSliderDto } from './dto/create-home-slider.dto';
import { UpdateHomeSliderDto } from './dto/update-home-slider.dto';
import { HomeSlider } from './entities/home-slider.entity';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';

@Injectable()
export class HomeSliderService {
    constructor(
        @InjectRepository(HomeSliderRepository)
        private readonly repository: HomeSliderRepository,
        private readonly spaceService: DoSpacesService
    ) { }

    async create(
        dto: CreateHomeSliderDto,
        files: { 
            image: UploadedMulterFileI
        }
    ): Promise<HomeSlider | Error> {
        if (files && files.image) {
            const image: any = await this.spaceService.uploadFile(files.image[0], 'HomeSlider/');
            dto.image = image;
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Home slider data created successfully", "data", data);
    }

    async update(
        id: string,
        dto: UpdateHomeSliderDto,
        files: { 
            image: UploadedMulterFileI
        }
    ): Promise<HomeSlider | Error> {
        const res : any = await this.repository.findOneEntity(id);
        if(!res){
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        if (files && files.image) {
            const image: any = await this.spaceService.uploadFile(files.image[0], 'HomeSlider/');
            dto.image = image;
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Home slider data updated successfully", "data", data);
    }

    async findAll(): Promise<HomeSlider[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Home slider data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<HomeSlider[] | Error> {
        const data = await this.repository.findByFilterQuery({id: id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Home slider data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Home slider data deleted successfully");
    }
}
