import { Body, Controller, Delete, Get, Param, Patch, Post, UseGuards } from '@nestjs/common';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard'
import { Constants } from 'src/utils/constants';
import { NecklaceSizeService } from './necklace-size.service';
import { CreateNecklaceSizeDto } from './dto/create-necklace-size.dto';
import { UpdateNecklaceSizeDto } from './dto/update-necklace-size.dto';

@Controller({ path: 'necklace-size', version: Constants.API_VERSION_1 })

export class NecklaceSizeController {
    constructor(private readonly service: NecklaceSizeService) { }

    @Post()
    @UseGuards(AdminAuthGuard)
    create(
        @Body() dto: CreateNecklaceSizeDto
    ) {
        return this.service.create(dto);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    update(
        @Param('id') id: string,
        @Body() dto: UpdateNecklaceSizeDto
    ) {
        return this.service.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
