import { Module } from '@nestjs/common';
import { OrderService } from './order.service';
import { OrderController } from './order.controller';
import { JwtModule } from '@nestjs/jwt';
import JwtConfigService from 'src/core/jwt/jwt-config.service';
import { TypeOrmModule } from '@nestjs/typeorm';
import { UsersRepository } from 'src/modules/users/user.repository';
import JwtHelper from 'src/core/jwt/jwt.helper';
import { ProductsRepository } from 'src/modules/product/product/product.repository';
import { OrderRepository } from './order-repository';
import { MailSenderService } from 'src/modules/mail-sender/mail-sender.service';
import { OrderDetailsRepository } from '../order-details/order-details.repository';
import { ShippingAddressRepository } from 'src/modules/address/shipping-address/shipping-address.repository';
import { GiftCardRepository } from 'src/modules/gift-card/gift-card.repository';
import { GiftCardDetailsRepository } from '../gift-card-details/gift-card-details.repository';
import { PaymentGatewayRepository } from 'src/modules/payment-gateway/payment-gateway.repository';
import { PaymentConfigurationRepository } from 'src/modules/payment-configuration/payment-configuration.repository';
import { CouponRepository } from 'src/modules/coupon/coupon.repository';

@Module({
  imports: [
    JwtModule.registerAsync({
      useClass: JwtConfigService
    }),
    TypeOrmModule.forFeature([
      UsersRepository,
      ProductsRepository,
      OrderRepository,
      OrderDetailsRepository,
      ShippingAddressRepository,
      GiftCardRepository,
      GiftCardDetailsRepository,
      PaymentGatewayRepository,
      PaymentConfigurationRepository,
      CouponRepository
    ]),
  ],
  controllers: [OrderController],
  providers: [OrderService, JwtHelper, MailSenderService]
})
export class OrderModule {}
