import { Controller, Get, Post, Body, Patch, Param, Delete, Req, UseGuards, Query } from '@nestjs/common';
import { PaymentGatewayService } from './payment-gateway.service';
import { CreatePaymentGatewayDto } from './dto/create-payment-gateway.dto';
import { UpdatePaymentGatewayDto } from './dto/update-payment-gateway.dto';
import { Constants } from 'src/utils/constants';
import { AuthGuard } from 'src/core/guards/auth.guard';

@Controller({
    path: 'payment-gateway',
    version: Constants.API_VERSION_1
})

export class PaymentGatewayController {
  constructor(private readonly paymentGatewayService: PaymentGatewayService) {}

    @Post('/payment')
    @UseGuards(AuthGuard)
    payment(@Body() dto: CreatePaymentGatewayDto, @Req() request: any) {
        return this.paymentGatewayService.payment(dto, request);
    }

    @Patch('/refund/:id')
    @UseGuards(AuthGuard)
    refund(@Body() dto: any, @Param('id') id: string) {
        return this.paymentGatewayService.refund(id, dto);
    }

    // @Get('/professional')
    // @UseGuards(AuthGuard)
    // professionalPaymentLog(
    //     @Req() request: any,
    // ) {
    //     return this.paymentGatewayService.professionalPaymentLog(request);
    // }

    @Get()
    @UseGuards(AuthGuard)
    findAll(
        @Query('transId') transId?: string,
        @Query('startDate') startDate?: Date,
        @Query('endDate') endDate?: Date,
        @Query('userName') userName?: string,
        @Query('orderId') orderId?: string
    ) {
        return this.paymentGatewayService.findAll(transId, startDate, endDate, userName, orderId);
    }
}
