import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { ProductHighlightRepository } from './product-highlight.repository';
import { CreateProductHighlightDto } from './dto/create-product-highlight.dto';
import { UpdateProductHighlightDto } from './dto/update-product-highlight.dto';
import { ProductHighlight } from './entities/product-highlight.entity';

@Injectable()
export class ProductHighlightService {
    constructor(
        @InjectRepository(ProductHighlightRepository)
        private readonly repository: ProductHighlightRepository
    ) { }

    async create(dto: CreateProductHighlightDto): Promise<ProductHighlight | Error> {
        const res: any = await this.repository.findByName(dto.name);
        if (res.length > 0) {
            throw new HttpException(
                "Product highlight name already exists.",
                HttpStatus.BAD_REQUEST
            );
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Product highlight created successfully", "data", data);
    }

    async findAll(): Promise<ProductHighlight[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product highlight fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateProductHighlightDto): Promise<ProductHighlight | Error> {
        const category: any = await this.repository.findOneEntity(id);
        if (!category) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product highlight updated successfully", "data", data);
    }

    async findOne(id: string): Promise<ProductHighlight[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product highlight fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Product highlight deleted successfully");
    }
}
