import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateProductMaterialVariantsDto } from "./dto/create-product-material-variants.dto";
import { UpdateProductMaterialVariantsDto } from "./dto/update-product-material-variants.dto";
import { ProductMaterialVariants } from "./entities/product-material-variants.entity";

@EntityRepository(ProductMaterialVariants)
export class ProductMaterialVariantsRepository extends Repository<ProductMaterialVariants> {

    async createEntity(dto: CreateProductMaterialVariantsDto): Promise<ProductMaterialVariants | Error> {
        try {
            const { productId, productName, materialId, materialName } = dto;
            const entity = this.create({
                productId,
                productName,
                materialId,
                materialName
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ProductMaterialVariants[] | Error> {
        try {
            return await this.find({
                order: { createdAt: "DESC" },
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ProductMaterialVariants | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateProductMaterialVariantsDto): Promise<ProductMaterialVariants | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ProductMaterialVariants)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async findByName(name: string): Promise<ProductMaterialVariants[] | Error> {
        try {
            return await this.find({
                where: { 
                    name: name, 
                    isDeleted: false 
                }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteMaterialVariant(id: any): Promise<any | Error> {
        try {
            const deleteResult = await getConnection()
                .createQueryBuilder()
                .delete()
                .from(ProductMaterialVariants)
                .where("productId = :productId", { productId: id })
                .execute();
            if (deleteResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async bulkInsertMaterialVariant(newMaterial: any): Promise<any | Error> {
        try {
            const insertResult = await getConnection()
                .createQueryBuilder()
                .insert()
                .into(ProductMaterialVariants)
                .values(newMaterial)
                .execute();

            if (insertResult.raw.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async updateProductMaterialValues(id: any, newMaterialEntity: any): Promise<any | Error> {
        try {
            const deleteCurrent = await this.deleteMaterialVariant(id);
            await this.bulkInsertMaterialVariant(newMaterialEntity)
        } catch (e) {
            return e;
        }
    }
}