import { EntityRepository, getConnection, getManager, Repository } from "typeorm";
import { CreateProductStockImportDto } from "./dto/create-product-stock-import.dto";
import { UpdateProductStockImportDto } from "./dto/update-product-stock-import.dto";
import { ProductStockImport } from "./entity/product-stock-import.entity";


@EntityRepository(ProductStockImport)
export class ProductStockImportRepository extends Repository<ProductStockImport> {

    async createEntity(
        dto: CreateProductStockImportDto
    ): Promise<ProductStockImport | Error> {
        try {
            const { StockID, Pid, Name, Price, CurrentStock, NewStock, QuantityReorder, NewTotalStock, Weight, Color, Size, Tag, Highlight, Material, Sku,ParentCategory, SubCategory, ChildCategory, Status  } = dto;
            const entity = this.create({ StockID, Pid, Name, Price, CurrentStock, NewStock, QuantityReorder, NewTotalStock, Weight, Color, Size, Tag, Highlight, Material, Sku, ParentCategory, SubCategory, ChildCategory, Status });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findAllEntities(): Promise<any | Error> {
        try {
            let sql = ` SELECT 
                            p.StockID, COUNT(p.StockID) as 'total_product',
                            IFNULL(SUM(p.CurrentStock), 0) as 'current_stock', 
                            IFNULL(SUM(p.NewStock), 0) as 'new_stock', 
                            IFNULL(SUM(p.NewTotalStock), 0) as 'total_stock' 
                        FROM product_stock_imports as p 
                        GROUP BY p.StockID;`
            let sqlTotal = `SELECT p.* FROM product_stock_imports as p group by p.id;`
            console.log(sql);
            console.log(sqlTotal);
            const entityManager = getManager();
            const data = await entityManager.query(sql);
            const totalData = await entityManager.query(sqlTotal);
            const count = totalData.length;

            return data;
        }
        catch (e) {
            return e;
        }
    }
    
    async findByFilterQuery(query : any): Promise<ProductStockImport[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(
        id: string
    ): Promise<ProductStockImport | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }


    async findAllStockListEntity(
        id: string
    ): Promise<ProductStockImport[] | Error> {
        try {
            return await this.find({
                where: {
                    StockID: id
                }
            });
        }
        catch (e) {
            return e;
        }
    }


    async updateEntity(
        id: string,
        dto: UpdateProductStockImportDto
    ): Promise<ProductStockImport | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ProductStockImport)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if(updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch(e) {
            return e;
        }
    }

    async findStockIdEntity(): Promise<any | Error> {
        const data = await this.find({
            select: ["StockID"]
        });
        return data;
    }


}