import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateQuickLinksDto } from "./dto/create-quick-links.dto";
import { UpdateQuickLinksDto } from "./dto/update-quick-links.dto";
import { QuickLinks } from "./entities/quick-links.entity";

@EntityRepository(QuickLinks)
export class QuickLinksRepository extends Repository<QuickLinks> {
    async createEntity(dto: CreateQuickLinksDto): Promise<QuickLinks | Error> {
        try {
            const { name, link } = dto;
            const entity = this.create({
                name,
                link
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<QuickLinks | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateQuickLinksDto): Promise<QuickLinks | Error> {
        try {
            await this.update(id, {
                name : dto.name,
                link : dto.link
            });
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query : any): Promise<QuickLinks[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(QuickLinks)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if(updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch(e) {
            return e;
        }
    }
}