import { Module } from '@nestjs/common';

import { ConfigModule } from '@nestjs/config';
import { TypeOrmModule } from '@nestjs/typeorm';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { UsersRepository } from './modules/users/user.repository';
import { UsersModule } from './modules/users/users.module';
import { UsersService } from './modules/users/users.service';
import { AuthModule } from './modules/auth/auth.module';
import { JwtModule } from '@nestjs/jwt';
import { EmailNotifierModule } from './modules/email-notifier/email-notifier.module';
import JwtConfigService from './core/jwt/jwt-config.service';
import { MailerModule } from '@nestjs-modules/mailer';
import { HandlebarsAdapter } from '@nestjs-modules/mailer/dist/adapters/handlebars.adapter';
import { ServeStaticModule } from '@nestjs/serve-static';
import { join } from 'path';
import { FileUploadsModule } from './modules/file-uploads/file-uploads.module';
import { SendEmailModule } from './modules/send-email/send-email.module';
import { SendEmailService } from './modules/send-email/send-email.service';
import { SendEmailRepository } from './modules/send-email/send-email-repository';
import { EmailNotifierRepository } from './modules/email-notifier/email-notifier-repository';
import { FileUploadsService } from './modules/file-uploads/file-uploads.service';
import { CoreResourceModule } from './modules/core-resource/core-resource.module';
import { MailSenderModule } from './modules/mail-sender/mail-sender.module';
import { SpacesModule } from './modules/SpacesModule/spaces.module';
import { DoSpacesService } from './modules/SpacesModule/SpacesService/doSpacesService';
import { DoSpacesServicerovider } from './modules/SpacesModule/SpacesService';
import { StylePageSectionOneCmsModule } from './modules/CMS/style-page-section-one-cms/style-page-section-one-cms.module';
import { StylePageSectionThreeCmsModule } from './modules/CMS/style-page-section-three-cms/style-page-section-three-cms.module';
import { StylePageSectionFourCmsModule } from './modules/CMS/style-page-section-four-cms/style-page-section-four-cms.module';
import { StylePageSectionFiveCmsModule } from './modules/CMS/style-page-section-five-cms/style-page-section-five-cms.module';
import { HomePageCmsModule } from './modules/CMS/home-page-cms/home-page-cms.module';
import { HomePageSectionThreeCmsModule } from './modules/CMS/home-page-section-three-cms/home-page-section-three-cms.module';
import { HomePageSectionFourCmsModule } from './modules/CMS/home-page-section-four-cms/home-page-section-four-cms.module';
import { HomePageSectionSixCmsModule } from './modules/CMS/home-page-section-six-cms/home-page-section-six-cms.module';
import { HomePageSectionSevenCmsModule } from './modules/CMS/home-page-section-seven-cms/home-page-section-seven-cms.module';
import { TermsPolicyCmsModule } from './modules/CMS/terms-policy-cms/terms-policy-cms.module';
import { PrivacyPolicyCmsModule } from './modules/CMS/privacy-policy-cms/privacy-policy-cms.module';
import { ReturnPageCmsModule } from './modules/CMS/return-page-cms/return-page-cms.module';
import { CustomerReviewModule } from './modules/home/customer-review/customer-review.module';
import { SiteSocialLinksModule } from './modules/site-social-links/site-social-links.module';
import { HomeSliderModule } from './modules/home/home-slider/home-slider.module';
import { ContactPageCmsModule } from './modules/CMS/contact-page-cms/contact-page-cms.module';
import { HomePageSectionTwoModule } from './modules/home/home-page-section-two/home-page-section-two.module';
import { NewsletterCmsModule } from './modules/CMS/newsletter-cms/newsletter-cms.module';
import { FooterCmsModule } from './modules/CMS/footer-cms/footer-cms.module';
import { AboutPageCmsModule } from './modules/CMS/about-page-cms/about-page-cms.module';
import { GalleryModule } from './modules/gallery/gallery.module';
import { ProductPageCmsModule } from './modules/CMS/product-page-cms/product-page-cms.module';
import { ContactAddressModule } from './modules/contact/contact-address/contact-address.module';
import { ContactMessageModule } from './modules/contact/contact-message/contact-message.module';
import { ProductHighlightModule } from './modules/product/product-highlight/product-highlight.module';
import { BillingAddressModule } from './modules/address/billing-address/billing-address.module';
import { ShippingAddressModule } from './modules/address/shipping-address/shipping-address.module';
import { ProductMaterialModule } from './modules/product/product-material/product-material.module';
import { ProductTagModule } from './modules/product/product-tag/product-tag.module';
import { ProductTagVariantsModule } from './modules/product/product-tag-variants/product-tag-variants.module';
import { ProductSizeModule } from './modules/product/product-size/product-size.module';
import { ProductSizeVariantsModule } from './modules/product/product-size-variants/product-size-variants.module';
import { ProductColorModule } from './modules/product/product-color/product-color.module';
import { ProductColorVariantsModule } from './modules/product/product-color-variants/product-color-variants.module';
import { ProductParentCategoryModule } from './modules/product/product-parent-category/product-parent-category.module';
import { ProductSubCategoryModule } from './modules/product/product-sub-category/product-sub-category.module';
import { ProductChildCategoryModule } from './modules/product/product-child-category/product-child-category.module';
import { ProductImageGalleryModule } from './modules/product/product-image-gallery/product-image-gallery.module';
import { ProductHighlightVariantsModule } from './modules/product/product-highlight-variants/product-highlight-variants.module';
import { ProductMaterialVariantsModule } from './modules/product/product-material-variants/product-material-variants.module';
import { ProductModule } from './modules/product/product/product.module';
import { NewsletterSubscriberModule } from './modules/newsletter-subscriber/newsletter-subscriber.module';
import { OrderModule } from './modules/orders/order/order.module';
import { GiftCardModule } from './modules/gift-card/gift-card.module';
import { DashboardModule } from './modules/dashboard/dashboard.module';
import { LearnPageCmsModule } from './modules/CMS/learn-page-cms/learn-page-cms.module';
import { GlossaryModule } from './modules/glossary/glossary.module';
import { GiftCardPageCmsModule } from './modules/CMS/gift-card-page-cms/gift-card-page-cms.module';
import { GiftGuideCmsModule } from './modules/CMS/gift-guide-cms/gift-guide-cms.module';
import { PromotionalPageCmsModule } from './modules/CMS/promotional-page-cms/promotional-page-cms.module';
import { RingSizeModule } from './modules/learn/ring-size/ring-size.module';
import { BraceletsSizeModule } from './modules/learn/bracelets-size/bracelets-size.module';
import { NecklaceSizeModule } from './modules/learn/necklace-size/necklace-size.module';
import { PaymentConfigurationModule } from './modules/payment-configuration/payment-configuration.module';
import { PaymentGatewayModule } from './modules/payment-gateway/payment-gateway.module';
import { CardInformationModule } from './modules/card-information/card-information.module';
import { CouponModule } from './modules/coupon/coupon.module';
import { HomeComponentCmsModule } from './modules/component-cms/home-component-cms/home-component-cms.module';
import { ShopComponentCmsModule } from './modules/component-cms/shop-component-cms/shop-component-cms.module';
import { StyleComponentCmsModule } from './modules/component-cms/style-component-cms/style-component-cms.module';
import { GalleryComponentCmsModule } from './modules/component-cms/gallery-component-cms/gallery-component-cms.module';
import { AboutComponentCmsModule } from './modules/component-cms/about-component-cms/about-component-cms.module';
import { CollectionComponentCmsModule } from './modules/component-cms/collection-component-cms/collection-component-cms.module';
import { LearnComponentCmsModule } from './modules/component-cms/learn-component-cms/learn-component-cms.module';
import { ContactComponentCmsModule } from './modules/component-cms/contact-component-cms/contact-component-cms.module';
import { GalleryPageCmsModule } from './modules/CMS/gallery-page-cms/gallery-page-cms.module';
import { PromotionalComponentCmsModule } from './modules/component-cms/promotional-component-cms/promotional-component-cms.module';
import { GiftCardComponentCmsModule } from './modules/component-cms/gift-card-component-cms/gift-card-component-cms.module';
import { GiftCardDetailsComponentCmsModule } from './modules/component-cms/gift-card-details-component-cms/gift-card-details-component-cms.module';
import { ProductDetailsComponentCmsModule } from './modules/component-cms/product-details-component-cms/product-details-component-cms.module';
import { PrivacyPolicyComponentCmsModule } from './modules/component-cms/privacy-policy-component-cms/privacy-policy-component-cms.module';
import { ReturnPolicyComponentCmsModule } from './modules/component-cms/return-policy-component-cms/return-policy-component-cms.module';
import { TermsPolicyComponentCmsModule } from './modules/component-cms/terms-policy-component-cms/terms-policy-component-cms.module';
import { ReportModule } from './modules/report/report.module';
import { VendorModule } from './modules/vendor/vendor.module';
import { CollectionPageModule } from './modules/CMS/collection-page-cms/collection-page-cms.module';
import { ShopGuideCmsModule } from './modules/CMS/shop-guide-cms/shop-guide-cms.module';
import { QuickLinksModule } from './modules/quick-links/quick-links.module';



@Module({
  imports: [
    ServeStaticModule.forRoot({
      rootPath: join(__dirname, '..', 'uploads'),
    }),
    ConfigModule.forRoot({ isGlobal: true }),
    TypeOrmModule.forRoot({
      type: 'mysql',
      host: process.env.HOST,
      port: parseInt(process.env.PORT),
      //username: process.env.USERNAME,
      username: 'root',
      password: process.env.PASSWORD,
      database: process.env.DATABASE,
      autoLoadEntities: true,
      synchronize: true,
      dropSchema: false
    }),
    TypeOrmModule.forFeature([UsersRepository]),
    TypeOrmModule.forFeature([SendEmailRepository]),
    TypeOrmModule.forFeature([EmailNotifierRepository]),
    JwtModule.registerAsync({
      useClass: JwtConfigService
    }),
    MailerModule.forRoot({
      transport: {
        host: process.env.EMAIL_HOST,
        port: parseInt(process.env.EMAIL_PORT),
        secure: true,
        auth: {
          user: process.env.EMAIL_USER,
          pass: process.env.EMAIL_PASS
        }
      },
      defaults: {
        from: `"${process.env.EMAIL_SENDER_NAME}" <${process.env.EMAIL_SENDER_MAIL}>`,
      },
      template: {
        dir: __dirname + '/templates/**/*',
        adapter: new HandlebarsAdapter(),
        options: {
          strict: true,
        }
      }
    }),
    UsersModule,
    AuthModule,
    EmailNotifierModule,
    FileUploadsModule,
    SendEmailModule,
    CoreResourceModule,
    MailSenderModule,
    SpacesModule,
    StylePageSectionOneCmsModule,
    StylePageSectionThreeCmsModule,
    StylePageSectionFourCmsModule,
    StylePageSectionFiveCmsModule,
    HomePageCmsModule,
    HomePageSectionThreeCmsModule,
    HomePageSectionFourCmsModule,
    HomePageSectionSixCmsModule,
    HomePageSectionSevenCmsModule,
    CollectionPageModule,
    TermsPolicyCmsModule,
    PrivacyPolicyCmsModule,
    CustomerReviewModule,
    SiteSocialLinksModule,
    HomeSliderModule,
    ReturnPageCmsModule,
    CustomerReviewModule,
    ContactPageCmsModule,
    HomePageSectionTwoModule,
    NewsletterCmsModule,
    FooterCmsModule,
    AboutPageCmsModule,
    ProductPageCmsModule,
    BillingAddressModule,
    ShippingAddressModule,
    GalleryModule,
    ProductPageCmsModule,
    ContactAddressModule,
    ContactMessageModule,
    ProductHighlightModule,
    ProductHighlightVariantsModule,
    ProductMaterialModule,
    ProductMaterialVariantsModule,
    ProductTagModule,
    ProductTagVariantsModule,
    ProductSizeModule,
    ProductSizeVariantsModule,
    ProductColorModule,
    ProductColorVariantsModule,
    ProductParentCategoryModule,
    ProductSubCategoryModule,
    ProductChildCategoryModule,
    ProductImageGalleryModule,
    ProductModule,
    NewsletterSubscriberModule,
    OrderModule,
    GiftCardModule,
    DashboardModule,
    LearnPageCmsModule,
    GlossaryModule,
    GiftCardPageCmsModule,
    GiftGuideCmsModule,
    PromotionalPageCmsModule,
    RingSizeModule,
    BraceletsSizeModule,
    NecklaceSizeModule,
    PaymentConfigurationModule,
    PaymentGatewayModule,
    CardInformationModule,
    CouponModule,
    HomeComponentCmsModule,
    ShopComponentCmsModule,
    StyleComponentCmsModule,
    GalleryComponentCmsModule,
    AboutComponentCmsModule,
    CollectionComponentCmsModule,
    LearnComponentCmsModule,
    ContactComponentCmsModule,
    GalleryPageCmsModule,
    PromotionalComponentCmsModule,
    GiftCardComponentCmsModule,
    GiftCardDetailsComponentCmsModule,
    ProductDetailsComponentCmsModule,
    PrivacyPolicyComponentCmsModule,
    ReturnPolicyComponentCmsModule,
    TermsPolicyComponentCmsModule,
    ReportModule,
    VendorModule,
    ShopGuideCmsModule,
    QuickLinksModule
  ],
  controllers: [AppController],
  providers: [AppService, UsersService, SendEmailService, FileUploadsService, DoSpacesService, DoSpacesServicerovider]
})
export class AppModule {}
