import { EntityRepository, getConnection, Repository } from "typeorm";
import { BaseCollectionPageDto } from "./dto/base-collection-page-cms.dto";
import { UpdateCollectionPageDto } from "./dto/update-collection-page-cms.dto";
import { CollectionPage } from "./entities/collection-page-cms.entity";

@EntityRepository(CollectionPage)
export class CollectionPageRepository extends Repository<CollectionPage> {
    async createEntity(dto: BaseCollectionPageDto): Promise<CollectionPage | Error> {
        try {
            const { 
                title,
                subTitle,
                blockOneImage,
                blockOneTitle,
                blockOneLink,
                blockTwoImage,
                blockTwoTitle,
                blockTwoLink,
                buttonText
            } = dto;
            const entity = this.create({
                title,
                subTitle,
                blockOneImage,
                blockOneTitle,
                blockOneLink,
                blockTwoImage,
                blockTwoTitle,
                blockTwoLink,
                buttonText
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<CollectionPage | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateCollectionPageDto): Promise<CollectionPage | Error> {
        try {
            await this.update(id, {
                title: dto.title,
                subTitle: dto.subTitle,
                blockOneImage: dto.blockOneImage,
                blockOneTitle: dto.blockOneTitle,
                blockOneLink: dto.blockOneLink,
                blockTwoImage: dto.blockTwoImage,
                blockTwoTitle: dto.blockTwoTitle,
                blockTwoLink: dto.blockTwoLink,
                buttonText: dto.buttonText
            });
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query : any): Promise<CollectionPage[] | Error> {
        try {
            return await this.find({
                where: { 
                    ...query, 
                    isDeleted: false 
                }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(CollectionPage)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if(updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch(e) {
            return e;
        }
    }
}