import { Controller, Get, Post, Body, HttpCode, UseGuards, HttpStatus, UseInterceptors, UploadedFiles } from '@nestjs/common';
import { FileFieldsInterceptor } from '@nestjs/platform-express';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { getMulterConfig } from 'src/core/multer.config';
import { Constants } from 'src/utils/constants';
import { LearnPageCmsService } from './learn-page-cms.service';
import { UpdateLearnPageCmsDto } from './dto/update-learn-page-cms.dto';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';

@Controller({ path: 'learn-page-cms', version: Constants.API_VERSION_1 })

export class LearnPageCmsController {
    constructor(private readonly service: LearnPageCmsService) { }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: 'sectionTwoImage', maxCount: 1 },
            { name: 'sectionFourImage', maxCount: 1 },
            { name: 'sectionSixImage', maxCount: 1 },
            { name: 'sectionSevenImage', maxCount: 1 },
            { name: 'sectionOneImage', maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateLearnPageCmsDto,
        @UploadedFiles() files: { 
            sectionTwoImage: UploadedMulterFileI,
            sectionFourImage: UploadedMulterFileI,
            sectionSixImage: UploadedMulterFileI,
            sectionSevenImage: UploadedMulterFileI,
            sectionOneImage: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
