import { Controller, Get, Post, Body, HttpCode, UseGuards, HttpStatus, UseInterceptors, UploadedFiles } from '@nestjs/common';
import { FileFieldsInterceptor } from '@nestjs/platform-express';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { getMulterConfig } from 'src/core/multer.config';
import { Constants } from 'src/utils/constants';
import { StylePageSectionOneCmsService } from './style-page-section-one-cms.service';
import { UpdateStylePageSectionOneCmsDto } from './dto/update-style-page-section-one-cms.dto';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';

@Controller({ path: 'style-page-sec-one-cms', version: Constants.API_VERSION_1 })

export class StylePageSectionOneCmsController {
    constructor(private readonly service: StylePageSectionOneCmsService) { }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: 'imageOne', maxCount: 1 },
            { name: 'imageTwo', maxCount: 1 },
            { name: 'imageThree', maxCount: 1 },
            { name: 'imageFour', maxCount: 1 },
            { name: 'imageFive', maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateStylePageSectionOneCmsDto,
        @UploadedFiles() files: { 
            imageOne: UploadedMulterFileI, 
            imageTwo: UploadedMulterFileI, 
            imageThree: UploadedMulterFileI, 
            imageFour: UploadedMulterFileI, 
            imageFive: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
