import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { FileUploadsService } from 'src/modules/file-uploads/file-uploads.service';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { StylePageSectionThreeCmsRepository } from './style-page-section-three-cms.repository';
import { UpdateStylePageSectionThreeCmsDto } from './dto/update-style-page-section-three-cms.dto';
import { StylePageSectionThreeCms } from './entities/style-page-section-three-cms.entity';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';

@Injectable()
export class StylePageSectionThreeCmsService {
    constructor(
        @InjectRepository(StylePageSectionThreeCmsRepository)
        private readonly repository: StylePageSectionThreeCmsRepository,
        private readonly fileService: FileUploadsService,
        private readonly doSpaceService: DoSpacesService
    ) { }

    async updateOrCreateData(
        dto: UpdateStylePageSectionThreeCmsDto,
        files: { 
            image: UploadedMulterFileI,
            imageTwo: UploadedMulterFileI,
        }
    ): Promise<StylePageSectionThreeCms | Error> {
        // process image one
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], 'stylePageSectionThreeCms/');
            dto.image = image;
        }

        // process image Two
        if (files && files.imageTwo) {
            const imageTwo: any = await this.doSpaceService.uploadFile(files.imageTwo[0], 'stylePageSectionThreeCms/');
            dto.imageTwo = imageTwo;
        }
        
        const isExists = await this.repository.find({isDeleted: false});
        if(Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if(!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        }
        else {
            let id = isExists[0].id;
            const data = await this.repository.UpdateEntity(dto, id);
            if(!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<StylePageSectionThreeCms[] | Error> {
        const data = await this.repository.findAll();
        if(!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Style page section three cms data fetched successfully", "data", data);
    }
}
