import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { FileUploadsService } from 'src/modules/file-uploads/file-uploads.service';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { TermsPolicyCmsRepository } from './terms-policy-cms.repository';
import { UpdateTermsPolicyCmsDto } from './dto/update-terms-policy-cms.dto';
import { TermsPolicyCms } from './entities/terms-policy-cms.entity';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';

@Injectable()
export class TermsPolicyCmsService {
    constructor(
        @InjectRepository(TermsPolicyCmsRepository)
        private readonly repository: TermsPolicyCmsRepository,
        private readonly fileService: FileUploadsService,
        private readonly doSpaceService: DoSpacesService
    ) { }

    async updateOrCreateData(
        dto: UpdateTermsPolicyCmsDto,
    ): Promise<TermsPolicyCms | Error> {
        const isExists = await this.repository.find({isDeleted: false});
        if(Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if(!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        }
        else {
            let id = isExists[0].id;
            const data = await this.repository.UpdateEntity(dto, id);
            if(!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<TermsPolicyCms[] | Error> {
        const data = await this.repository.findAll();
        if(!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Terms policy cms data fetched successfully", "data", data);
    }
}
