import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { BillingAddressRepository } from './billing-address.repository';
import { CreateBillingAddressDto } from './dto/create-billing-address.dto';
import { UpdateBillingAddressDto } from './dto/update-billing-address.dto';
import { BillingAddress } from './entities/billing-address.entity';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';

@Injectable()
export class BillingAddressService {
    constructor(
        @InjectRepository(BillingAddressRepository)
        private readonly repository: BillingAddressRepository,
        private readonly spaceService: DoSpacesService
    ) { }

    async create(
        dto: UpdateBillingAddressDto,
        request: any
    ): Promise<BillingAddress | Error> {
        const isUserExists = await this.repository.findByUserId(request.user.id);
        if(isUserExists) {
            let key = isUserExists['id'];
            dto.userId = request.user.id;
            const data = await this.repository.updateEntity(key, dto);
            if(!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Billing Address Updated Successfully", "data", data);
        }
        else {
            dto.userId = request.user.id;
            const data = await this.repository.createEntity(dto);
            if(!data) {
                throw new HttpException(
                    Constants.CREATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(201, "Billing Address Created Successfully", "data", data);
        }
    }

    async update(
        id: string,
        dto: UpdateBillingAddressDto,
        request: any
    ): Promise<BillingAddress | Error> {
        const res : any = await this.repository.findOneEntity(id);
        if(!res){
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        dto.userId = request.user.id;
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Billing address data updated successfully", "data", data);
    }

    async findAll(): Promise<BillingAddress[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Billing address data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<BillingAddress[] | Error> {
        const data = await this.repository.findByFilterQuery({id: id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Billing address data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Billing address data deleted successfully");
    }
}
