import { Controller, Post, Body, UseGuards, Req, Patch, HttpCode, HttpStatus } from '@nestjs/common';
import { AuthGuard } from 'src/core/guards/auth.guard';
import { Constants } from '../../utils/constants';
import { AuthService } from './auth.service';
import { LoginAuthDto } from './dto/login-auth.dto';
import { RegisterAuthDto } from './dto/register-auth.dto';
import { ResetPasswordRequestDto } from './dto/reset-password.dto';
import { UserApproveAuthDto } from './dto/user-approve-auth.dto';

@Controller({
    path: 'auth',
    version: Constants.API_VERSION_1
})
export class AuthController {

    constructor(private readonly authService: AuthService) { }

    @Post('customer/login')
    async login(@Body() dto: LoginAuthDto) {
        return await this.authService.login(dto);
    }

    @Post('admin/login')
    async loginAdmin(@Body() dto: LoginAuthDto) {
        return await this.authService.loginAdmin(dto);
    }

    @Post('/change-password')
    @HttpCode(HttpStatus.OK)
    @UseGuards(AuthGuard)
    async changePassword(@Body('currentPassword') currentPassword: string , @Body('newPassword') newPassword : string , @Req() request : any) {
        return await this.authService.changePassword(currentPassword ,newPassword, request );
    }

    @Post('/forgot-password')
    async forgotPassword(@Body() dto: ResetPasswordRequestDto) {
        return await this.authService.forgotPassword(dto);
    }


    @Post('/register')
    async register(@Body() dto: RegisterAuthDto) {
        return await this.authService.register(dto);
    }

    @Post('/validate-token')
    async verifyToken(@Req() reg: any) {
        return await this.authService.validateRequest(reg);
    }
}
