import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateCardInformationDto } from "./dto/create-card-information.dto";
import { UpdateCardInformationDto } from "./dto/update-card-information.dto";
import { CardInformation } from "./entities/card-information.entity";



@EntityRepository(CardInformation)
export class CardInformationRepository extends Repository<CardInformation> {


    async createEntity(
        dto: CreateCardInformationDto
    ): Promise<CardInformation | Error> {
        try {
            const entity = this.create(dto);
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }


    async findByFilterQuery(query: any): Promise<CardInformation[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(
        id: string
    ): Promise<CardInformation | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }


    async updateCardInformation(
        id: string,
        dto: UpdateCardInformationDto
    ): Promise<CardInformation | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(CardInformation)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async findOneByCardInformationName(CardInformationName: string): Promise<any | Error> {
        try {
            return await this.findOne({
                where: { CardInformationName: CardInformationName, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

}