import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { NewsletterSubscriberRepository } from '../newsletter-subscriber/newsletter-subscriber.repository';
import { OrderRepository } from '../orders/order/order-repository';
import { ProductParentCategoryRepository } from '../product/product-parent-category/product-parent-category.repository';
import { ProductsRepository } from '../product/product/product.repository';
import { UsersRepository } from '../users/user.repository';


@Injectable()
export class DashboardService {
  constructor(
    @InjectRepository(ProductsRepository)
    private readonly productRepository: ProductsRepository,
    @InjectRepository(UsersRepository)
    private readonly userRepository: UsersRepository,
    @InjectRepository(NewsletterSubscriberRepository)
    private readonly subscriberRepository: NewsletterSubscriberRepository,
    @InjectRepository(OrderRepository)
    private readonly orderRepository: OrderRepository,
    @InjectRepository(ProductParentCategoryRepository)
    private readonly productParentCat: ProductParentCategoryRepository,
  ) { }

  async getAdminDashboardData() {
    const totalProducts = await this.productRepository.countProduct();
    const totalCustomers = await this.userRepository.countCustomer(3);
    const totalSubscribers = await this.subscriberRepository.countSubscriber();
    const totalOrders = await this.orderRepository.countOrder();
    const totalDeliveredOrders = await this.orderRepository.countDeliveredOrder('DELIVERED');
    const totalCancelledOrders = await this.orderRepository.countCancelledOrder('CANCELLED');
    const totalPendingOrders = await this.orderRepository.countPendingOrder('PENDING');
    const totalProcessingOrders = await this.orderRepository.countProcessingOrder('PROCESSING');
    const todayProducts = await this.productRepository.todayProducts();
    const monthlyCustomerData = await this.userRepository.monthlyCustomer();
    const topThreeProducts = await this.productRepository.topProducts();

    const responseData = {
      totalProducts: totalProducts,
      totalCustomers: totalCustomers,
      totalSubscribers: totalSubscribers,
      totalOrders: totalOrders,
      totalDeliveredOrders: totalDeliveredOrders,
      totalCancelledOrders: totalCancelledOrders,
      totalPendingOrders: totalPendingOrders,
      totalProcessingOrders: totalProcessingOrders,
      todayProducts: todayProducts,
      topThreeProducts: topThreeProducts,
      monthlyCustomer: {
        labels: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
        data: [
          monthlyCustomerData[0],
          monthlyCustomerData[1],
          monthlyCustomerData[2],
          monthlyCustomerData[3],
          monthlyCustomerData[4],
          monthlyCustomerData[5],
          monthlyCustomerData[6],
          monthlyCustomerData[7],
          monthlyCustomerData[8],
          monthlyCustomerData[9],
          monthlyCustomerData[10],
          monthlyCustomerData[11]]
      }
    };

    return responseData;
  }

  async getCustomerDashboardData(user: any): Promise<any | Error> {
    const totalOrders = await this.orderRepository.countUserOrder(user.id);
    const totalDeliveredOrders = await this.orderRepository.countUserDeliveredOrder(user.id, 'DELIVERED');
    const totalCancelledOrders = await this.orderRepository.countUserCancelledOrder(user.id, 'CANCELLED');
    const totalShippedOrders = await this.orderRepository.countUserShippedOrder(user.id, 'SHIPPED');
    const totalPendingOrders = await this.orderRepository.countUserPendingOrder(user.id, 'PENDING');
    const todayOrderList = await this.orderRepository.todayOrderList(user.id);

    const responseData = {
      totalOrders: totalOrders ? totalOrders : 0,
      totalDeliveredOrders: totalDeliveredOrders ? totalDeliveredOrders : 0,
      totalCancelledOrders: totalCancelledOrders ? totalCancelledOrders : 0,
      totalShippedOrders: totalShippedOrders ? totalShippedOrders : 0,
      totalPendingOrders: totalPendingOrders ? totalPendingOrders : 0,
      todayOrderList: todayOrderList ? todayOrderList : []
    }

    return responseData;
  }
}
