import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateGalleryDto } from "./dto/create-gallery.dto";
import { UpdateGalleryDto } from "./dto/update-gallery.dto";
import { Gallery } from "./entities/gallery.entity";

@EntityRepository(Gallery)
export class GalleryRepository extends Repository<Gallery> {
    async createEntity(dto: CreateGalleryDto): Promise<Gallery | Error> {
        try {
            const { name, image, link } = dto;
            const entity = this.create({
                name,
                image,
                link
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<Gallery | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateGalleryDto): Promise<Gallery | Error> {
        try {
            await this.update(id, {
                name : dto.name,
                image : dto.image,
                link : dto.link
            });
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query : any): Promise<Gallery[] | Error> {
        try {
            return await this.find({
                where: { 
                    ...query, 
                    isDeleted: false 
                }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(Gallery)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if(updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch(e) {
            return e;
        }
    }
}