import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateRingSizeDto } from "./dto/create-ring-size.dto";
import { UpdateRingSizeDto } from "./dto/update-ring-size.dto";
import { RingSize } from "./entities/ring-size.entity";

@EntityRepository(RingSize)
export class RingSizeRepository extends Repository<RingSize> {
    async createEntity(dto: CreateRingSizeDto): Promise<RingSize | Error> {
        try {
            const { size, circumference } = dto;
            const entity = this.create({
                size,
                circumference
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<RingSize | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateRingSizeDto): Promise<RingSize | Error> {
        try {
            await this.update(id, {
                size : dto.size,
                circumference : dto.circumference
            });
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query : any): Promise<RingSize[] | Error> {
        try {
            return await this.find({
                order: {createdAt: "DESC"},
                where: { 
                    ...query, 
                    isDeleted: false 
                }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(RingSize)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if(updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch(e) {
            return e;
        }
    }
}