import { MailerService } from '@nestjs-modules/mailer';
import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { Constants } from '../../utils/constants';
import { AdminNotifyDto } from './dto/admin-notify.dto';
import { CreateAdminMailSenderDto } from './dto/create-admin-mail-sender.dto';
import { CreateListingStatusDto } from './dto/create-listing-status.dto';
import { CreateMailSenderDto } from './dto/create-mail-sender.dto';
import { CreateNewListingDto } from './dto/create-new-listing.dto';
import { ResetPasswordMailDto } from './dto/create-reset-password-mail.dto';
import { CreateFranchiseMailSenderDto } from './dto/franchise-mail-sender.dto';

@Injectable()
export class MailSenderService {

    constructor(private readonly mailerService: MailerService) { }

    async send(dto: CreateMailSenderDto) {
        console.log("Init mail");
        const { to, from, subject, username } = dto;
        const result = await this.mailerService
            .sendMail({
                to: to, // list of receivers
                bcc: ["frank@neutrix.co"], // list of receivers
                from: from, // sender address
                subject: subject,
                template: './templates/mail', // The `.pug` or `.hbs` extension is appended automatically.
                context: {  // Data to be sent to template engine.
                    username: username,
                }, // HTML body content
            }).catch((err) => {
                console.log("Error Found");
                console.log(err);
                throw new HttpException(
                    Constants.GENERIC_ERROR,
                    HttpStatus.INTERNAL_SERVER_ERROR
                );
            });
        console.log('complete' + result);
        return {
            message: "mail sent to " + to
        };
    }


    async accocuntCreateAdminNotify(dto: CreateAdminMailSenderDto) {
        const { to, from, subject, name, email } = dto;
        const result = await this.mailerService
            .sendMail({
                to: to, // list of receivers
                bcc: ["frank@neutrix.co"], // list of receivers
                from: from, // sender address
                subject: subject,
                template: './templates/account-create-admin', // The `.pug` or `.hbs` extension is appended automatically.
                context: {  // Data to be sent to template engine.
                    name: name,
                    email: email
                }, // HTML body content
            }).catch((err) => {
                console.log(err);
                throw new HttpException(
                    Constants.GENERIC_ERROR,
                    HttpStatus.INTERNAL_SERVER_ERROR
                );
            });
        console.log('complete' + result);
        return {
            message: "mail sent to " + to
        };
    }


    async accocuntCreateCustomerNotify(dto: CreateMailSenderDto) {
        const { to, from, subject, username, password } = dto;
        const result = await this.mailerService
            .sendMail({
                to: to, // list of receivers
                bcc: ["frank@neutrix.co"], // list of receivers
                from: from, // sender address
                subject: subject,
                template: './templates/accountcreatecustomer', // The `.pug` or `.hbs` extension is appended automatically.
                context: {  // Data to be sent to template engine.
                    username: username,
                    password: password
                }, // HTML body content
            }).catch((err) => {
                console.log(err);
                throw new HttpException(
                    Constants.GENERIC_ERROR,
                    HttpStatus.INTERNAL_SERVER_ERROR
                );
            });
        console.log('complete' + result);
        return {
            message: "mail sent to " + to
        };
    }


    async franchiseCreateCustomerNotify(dto: CreateFranchiseMailSenderDto) {
        const { to, from, subject, firstName,
            lastName,
            franchiseName,
            phone,
            email,
            state,
            city,
            zipCode,
            country,
            notes } = dto;
        const result = await this.mailerService
            .sendMail({
                to: to, // list of receivers
                bcc: ["frank@neutrix.co"], // list of receivers
                from: from, // sender address
                subject: subject,
                template: './templates/create_franchise_customer_notify', // The `.pug` or `.hbs` extension is appended automatically.
                context: {  // Data to be sent to template engine.
                    firstName: firstName,
                    lastName: lastName,
                    franchiseName: franchiseName,
                    phone: phone,
                    email: email,
                    state: state,
                    city: city,
                    zipCode: zipCode,
                    country: country,
                    notes: notes
                }, // HTML body content
            }).catch((err) => {
                console.log(err);
                throw new HttpException(
                    Constants.GENERIC_ERROR,
                    HttpStatus.INTERNAL_SERVER_ERROR
                );
            });
        console.log('complete' + result);
        return {
            message: "mail sent to " + to
        };
    }

    async franchiseCreateAdminNotify(dto: CreateFranchiseMailSenderDto) {
        const { to, from, subject, firstName,
            lastName,
            franchiseName,
            phone,
            email,
            state,
            city,
            zipCode,
            country,
            notes } = dto;
        const result = await this.mailerService
            .sendMail({
                to: to, // list of receivers
                bcc: ["frank@neutrix.co"], // list of receivers
                from: from, // sender address
                subject: subject,
                template: './templates/create_franchise_admin_notify', // The `.pug` or `.hbs` extension is appended automatically.
                context: {  // Data to be sent to template engine.
                    firstName: firstName,
                    lastName: lastName,
                    franchiseName: franchiseName,
                    phone: phone,
                    email: email,
                    state: state,
                    city: city,
                    zipCode: zipCode,
                    country: country,
                    notes: notes
                }, // HTML body content
            }).catch((err) => {
                console.log(err);
                throw new HttpException(
                    Constants.GENERIC_ERROR,
                    HttpStatus.INTERNAL_SERVER_ERROR
                );
            });
        console.log('complete' + result);
        return {
            message: "mail sent to " + to
        };
    }

    async userApprovalNotify(dto: CreateMailSenderDto) {
        const { to, from, subject, username } = dto;
        const result = await this.mailerService
            .sendMail({
                to: to, // list of receivers\
                bcc: ["frank@neutrix.co"], // list of receivers
                from: from, // sender address
                subject: subject,
                template: './templates/approval-notify', // The `.pug` or `.hbs` extension is appended automatically.
                context: {  // Data to be sent to template engine.
                    username: username,
                }, // HTML body content
            }).catch((err) => {
                console.log(err);
                throw new HttpException(
                    Constants.GENERIC_ERROR,
                    HttpStatus.INTERNAL_SERVER_ERROR
                );
            });
        console.log('complete' + result);
        return {
            message: "mail sent to " + to
        };
    }


    async adminNotify(dto: AdminNotifyDto) {
        const { to, from, subject, name, email } = dto;
        const result = await this.mailerService
            .sendMail({
                to: to, // list of receivers
                bcc: ["frank@neutrix.co"], // list of receivers
                from: from, // sender address
                subject: subject,
                template: './templates/admin-notify', // The `.pug` or `.hbs` extension is appended automatically.
                context: {  // Data to be sent to template engine.
                    name: name,
                    email: email
                }, // HTML body content
            }).catch((err) => {
                console.log(err);
                throw new HttpException(
                    Constants.GENERIC_ERROR,
                    HttpStatus.INTERNAL_SERVER_ERROR
                );
            });
        console.log('complete' + result);
        return {
            message: "mail sent to " + to
        };
    }


    async sendListingNotification(dto: CreateListingStatusDto) {
        const { to, from, subject, listingOwner, listingStatus, listingID } = dto;
        const result = await this.mailerService
            .sendMail({
                to: to, // list of receivers
                bcc: ["frank@neutrix.co"], // list of receivers
                from: from, // sender address
                subject: subject,
                template: './templates/listingnotification', // The `.pug` or `.hbs` extension is appended automatically.
                context: {  // Data to be sent to template engine.
                    listingOwner: listingOwner,
                    listingStatus: listingStatus,
                    listingID: listingID
                }, // HTML body content
            }).catch((err) => {
                console.log(err);
                throw new HttpException(
                    Constants.GENERIC_ERROR,
                    HttpStatus.INTERNAL_SERVER_ERROR
                );
            });
        console.log('complete' + result);
        console.log('complete' + to);
        return {
            message: "mail sent to " + to
        };
    }

    async sendNewListingNotification(dto: CreateNewListingDto) {
        const { to, from, subject, listingOwner, listingStatus, listingID } = dto;
        const result = await this.mailerService
            .sendMail({
                to: to, // list of receivers
                bcc: ["frank@neutrix.co"], // list of receivers
                from: from, // sender address
                subject: subject,
                template: './templates/newlistingnotification', // The `.pug` or `.hbs` extension is appended automatically.
                context: {  // Data to be sent to template engine.
                    listingOwner: listingOwner,
                    listingStatus: listingStatus,
                    listingID: listingID,
                }, // HTML body content
            }).catch((err) => {
                console.log(err);
                throw new HttpException(
                    Constants.GENERIC_ERROR,
                    HttpStatus.INTERNAL_SERVER_ERROR
                );
            });
        console.log('complete' + result);
        console.log('complete' + to);
        return {
            message: "mail sent to " + to
        };
    }

    async sendPasswordResetRequestMail(dto: ResetPasswordMailDto) {
        const { to, from, subject, username, token } = dto;
        const result = await this.mailerService
            .sendMail({
                to: to, // list of receivers
                bcc: ["f.bhuyian@gmail.com"], // list of receivers
                from: from, // sender address
                subject: subject,
                template: './templates/password-reset-request-mail', // The `.pug` or `.hbs` extension is appended automatically.
                context: {  // Data to be sent to template engine.
                    username: username,
                    token: token,
                }, // HTML body content
            }).catch((err) => {
                console.log(err);
                throw new HttpException(
                    Constants.GENERIC_ERROR,
                    HttpStatus.INTERNAL_SERVER_ERROR
                );
            });
        console.log('complete' + result);
        console.log('complete' + to);
        return {
            message: "mail sent to " + to
        };
    }
}
