import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateNewsletterSubscriberDto } from "./dto/create-newsletter-subscriber.dto";
import { UpdateNewsletterSubscriberDto } from "./dto/update-newsletter-subscriber.dto";
import { NewsletterSubscriber } from "./entities/newsletter-subscriber.entity";



@EntityRepository(NewsletterSubscriber)
export class NewsletterSubscriberRepository extends Repository<NewsletterSubscriber> {

    async createEntity(
        dto: CreateNewsletterSubscriberDto
    ): Promise<NewsletterSubscriber | Error> {
        try {
            const entity = this.create(dto);
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query : any): Promise<NewsletterSubscriber[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }



    async findOneEntity(
        id: string
    ): Promise<NewsletterSubscriber | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(
        id: string,
        dto: UpdateNewsletterSubscriberDto
    ): Promise<NewsletterSubscriber | Error> {
        try {
            await this.update(id, {
                email: dto.email
            });

            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(NewsletterSubscriber)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if(updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch(e) {
            return e;
        }
    }

    async countSubscriber(): Promise<any | Error> {
        try {
            return await this.count({
                where:{ isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }
}