import { Controller, Get, Post, Body, Patch, Param, Delete, UseGuards, Req, Query } from '@nestjs/common';
import { OrderService } from './order.service';
import { CreateOrderDto } from './dto/create-order.dto';
import { UpdateOrderDto } from './dto/update-order.dto';
import { Constants } from 'src/utils/constants';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { CreateOrderByAdminDto } from './dto/create-order-admin.dto';
import { AuthGuard } from 'src/core/guards/auth.guard';
import { InvoicePaymentDto } from './dto/invoice-payment.dto';
import { CreateOrderGuestDto } from './dto/create-order-guest.dto';

@Controller({ path: 'orders', version: Constants.API_VERSION_1 })
export class OrderController {
  constructor(private readonly orderService: OrderService) { }

  @Post('/admin')
  @UseGuards(AdminAuthGuard)
  createOrderByAdmin(@Body() createOrderByAdminDto: CreateOrderByAdminDto, @Req() req: any) {
    return this.orderService.createOrderByAdmin(createOrderByAdminDto, req.user);
  }


  @Post('/customer')
  @UseGuards(AuthGuard)
  createOrderByCustomer(@Body() dto: CreateOrderDto, @Req() req: any) {
    return this.orderService.createOrderByCustomer(dto, req.user);
  }

  @Post('/guest')
  createOrderByGuest(@Body() dto: CreateOrderGuestDto) {
    return this.orderService.createOrderByGuest(dto);
  }

  @Post('/payment')
  @UseGuards(AuthGuard)
  invoicePayment(@Body() dto: InvoicePaymentDto, @Req() req: any) {
    return this.orderService.invoicePayment(dto, req.user);
  }

  @Get('/customer-orders')
  @UseGuards(AuthGuard)
  async getOrdersByCustomer(@Req() req: any, @Query('limit') limit: number, @Query('page') page: number) {
    return await this.orderService.getOrdersByCustomer(req, limit, page);
  }

  @Get()
  @UseGuards(AdminAuthGuard)
  async findAll(
    @Query('limit') limit: number,
    @Query('page') page: number,
    @Query('paymentStatus') paymentStatus?: string,
    @Query('deliveryStatus') deliveryStatus?: string,
    @Query('startDate') startDate?: Date,
    @Query('endDate') endDate?: Date,
    @Query('customerName') customerName?: string,
    @Query('orderId') orderId?: string
  ) {
    return await this.orderService.findAll(limit, page, paymentStatus, deliveryStatus, startDate, endDate, customerName, orderId);
  }

  @Get('/:id')
  @UseGuards(AuthGuard)
  async findOne(@Param('id') id: string) {
    return await this.orderService.findOne(id);
  }

  @Patch('/:id')
  update(@Param('id') id: string, @Body() dto: UpdateOrderDto) {
    return this.orderService.update(id, dto);
  }

  @Delete(':id')
  @UseGuards(AdminAuthGuard)
  async remove(@Param('id') id: string) {
    return await this.orderService.remove(id);
  }
}
