import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateProductChildCategoryDto } from "./dto/create-product-child-category.dto";
import { UpdateProductChildCategoryDto } from "./dto/update-product-child-category.dto";
import { ProductChildCategory } from "./entities/product-child-category.entity";

@EntityRepository(ProductChildCategory)
export class ProductChildCategoryRepository extends Repository<ProductChildCategory> {

    async createEntity(dto: CreateProductChildCategoryDto): Promise<ProductChildCategory | Error> {
        try {
            const { name, subCategoryId, subCategoryName, parentCategoryId, parentCategoryName } = dto;
            const entity = this.create({
                name,
                subCategoryId,
                subCategoryName,
                parentCategoryId,
                parentCategoryName
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ProductChildCategory[] | Error> {
        try {
            return await this.find({
                order: { createdAt: "DESC" },
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ProductChildCategory | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateProductChildCategoryDto): Promise<ProductChildCategory | Error> {
        try {
            await this.update(id, {
                name: dto.name,
                subCategoryId: dto.subCategoryId,
                subCategoryName: dto.subCategoryName,
                parentCategoryId: dto.parentCategoryId,
                parentCategoryName: dto.parentCategoryName
            });
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ProductChildCategory)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async findByName(name: string): Promise<ProductChildCategory[] | Error> {
        try {
            return await this.find({
                where: { 
                    name: name, 
                    isDeleted: false 
                }
            });
        }
        catch (e) {
            return e;
        }
    }

    async findAllEntitiesSelect(query: any): Promise<ProductChildCategory[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }
}