import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { ProductChildCategoryRepository } from './product-child-category.repository';
import { CreateProductChildCategoryDto } from './dto/create-product-child-category.dto';
import { UpdateProductChildCategoryDto } from './dto/update-product-child-category.dto';
import { ProductChildCategory } from './entities/product-child-category.entity';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';

@Injectable()
export class ProductChildCategoryService {
    constructor(
        @InjectRepository(ProductChildCategoryRepository)
        private readonly repository: ProductChildCategoryRepository,
        private readonly doSpaceService: DoSpacesService
    ) { }

    async create(
        dto: CreateProductChildCategoryDto): Promise<ProductChildCategory | Error> {
        const res: any = await this.repository.findByName(dto.name);
        if (res.length > 0) {
            throw new HttpException(
                "Product child category name already exists.",
                HttpStatus.BAD_REQUEST
            );
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Product child category created successfully", "data", data);
    }

    async findAll(): Promise<ProductChildCategory[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product child category fetched successfully", "data", data);
    }

    async update(
        id: string,
        dto: UpdateProductChildCategoryDto
    ): Promise<ProductChildCategory | Error> {
        const productChildCategory: any = await this.repository.findOneEntity(id);
        if (!productChildCategory) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }

        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product child category updated successfully", "data", data);
    }

    async findOne(id: string): Promise<ProductChildCategory[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product child category fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Product child category deleted successfully");
    }
}
