import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { ProductColorRepository } from './product-color.repository';
import { CreateProductColorDto } from './dto/create-product-color.dto';
import { UpdateProductColorDto } from './dto/update-product-color.dto';
import { ProductColor } from './entities/product-color.entity';

@Injectable()
export class ProductColorService {
    constructor(
        @InjectRepository(ProductColorRepository)
        private readonly repository: ProductColorRepository
    ) { }

    async create(dto: CreateProductColorDto): Promise<ProductColor | Error> {
        const res: any = await this.repository.findByName(dto.name);
        if (res.length > 0) {
            throw new HttpException(
                "Product color name already exists.",
                HttpStatus.BAD_REQUEST
            );
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Product color created successfully", "data", data);
    }

    async findAll(): Promise<ProductColor[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product color fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateProductColorDto): Promise<ProductColor | Error> {
        const productColor: any = await this.repository.findOneEntity(id);
        if (!productColor) {
            throw new HttpException(
                "Product color not found.",
                HttpStatus.NOT_FOUND
            );
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product color updated successfully", "data", data);
    }

    async findOne(id: string): Promise<ProductColor[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product color fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Product color deleted successfully");
    }
}
