import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { ProductHighlightVariantsRepository } from './product-highlight-variants.repository';
import { CreateProductHighlightVariantsDto } from './dto/create-product-highlight-variants.dto';
import { UpdateProductHighlightVariantsDto } from './dto/update-product-highlight-variants.dto';
import { ProductHighlightVariants } from './entities/product-highlight-variants.entity';

@Injectable()
export class ProductHighlightVariantsService {
    constructor(
        @InjectRepository(ProductHighlightVariantsRepository)
        private readonly repository: ProductHighlightVariantsRepository
    ) { }

    async create(dto: CreateProductHighlightVariantsDto): Promise<ProductHighlightVariants | Error> {
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Product highlight variants created successfully", "data", data);
    }

    async findAll(): Promise<ProductHighlightVariants[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product highlight variants fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateProductHighlightVariantsDto): Promise<ProductHighlightVariants | Error> {
        const ProductHighlightVariants: any = await this.repository.findOneEntity(id);
        if (!ProductHighlightVariants) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product highlight variants updated successfully", "data", data);
    }

    async findOne(id: string): Promise<ProductHighlightVariants[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product highlight variants fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Product highlight variants deleted successfully");
    }
}
