import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateProductHighlightDto } from "./dto/create-product-highlight.dto";
import { UpdateProductHighlightDto } from "./dto/update-product-highlight.dto";
import { ProductHighlight } from "./entities/product-highlight.entity";

@EntityRepository(ProductHighlight)
export class ProductHighlightRepository extends Repository<ProductHighlight> {

    async createEntity(dto: CreateProductHighlightDto): Promise<ProductHighlight | Error> {
        try {
            const { name } = dto;
            const entity = this.create({
                name
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ProductHighlight[] | Error> {
        try {
            return await this.find({
                order: { createdAt: "DESC" },
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ProductHighlight | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateProductHighlightDto): Promise<ProductHighlight | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ProductHighlight)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async findByName(name: string): Promise<ProductHighlight[] | Error> {
        try {
            return await this.find({
                where: { 
                    name: name, 
                    isDeleted: false 
                }
            });
        }
        catch (e) {
            return e;
        }
    }
}