import { EntityRepository, getConnection, Repository } from "typeorm";
import { ProductSize } from "../product-size/entities/product-size.entity";
import { CreateProductSizeVariantsDto } from "./dto/create-product-size-variants.dto";
import { UpdateProductSizeVariantsDto } from "./dto/update-product-size-variants.dto";
import { ProductSizeVariants } from "./entities/product-size-variants.entity";

@EntityRepository(ProductSizeVariants)
export class ProductSizeVariantsRepository extends Repository<ProductSizeVariants> {

    async createEntity(dto: CreateProductSizeVariantsDto): Promise<ProductSizeVariants | Error> {
        try {
            const { productId, productName, sizeId, sizeName } = dto;
            const entity = this.create({
                productId,
                productName,
                sizeId,
                sizeName
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ProductSizeVariants[] | Error> {
        try {
            return await this.find({
                order: { createdAt: "DESC" },
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ProductSizeVariants | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateProductSizeVariantsDto): Promise<ProductSizeVariants | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ProductSizeVariants)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async findByName(name: string): Promise<ProductSizeVariants[] | Error> {
        try {
            return await this.find({
                where: { 
                    name: name, 
                    isDeleted: false 
                }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteSizeVariant(id: any): Promise<any | Error> {
        try {
            const deleteResult = await getConnection()
                .createQueryBuilder()
                .delete()
                .from(ProductSizeVariants)
                .where("productId = :productId", { productId: id })
                .execute();
            if (deleteResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async bulkInsertSizeVariant(newSize: any): Promise<any | Error> {
        try {
            const insertResult = await getConnection()
                .createQueryBuilder()
                .insert()
                .into(ProductSizeVariants)
                .values(newSize)
                .execute();

            if (insertResult.raw.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async updateProductSizeValues(id: any, newSizeEntity: any): Promise<any | Error> {
        try {
            const deleteCurrent = await this.deleteSizeVariant(id);
            await this.bulkInsertSizeVariant(newSizeEntity)
        } catch (e) {
            return e;
        }
    }
}