import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateProductSizeDto } from "./dto/create-product-size.dto";
import { UpdateProductSizeDto } from "./dto/update-product-size.dto";
import { ProductSize } from "./entities/product-size.entity";

@EntityRepository(ProductSize)
export class ProductSizeRepository extends Repository<ProductSize> {

    async createEntity(dto: CreateProductSizeDto): Promise<ProductSize | Error> {
        try {
            const { name } = dto;
            const entity = this.create({
                name
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ProductSize[] | Error> {
        try {
            return await this.find({
                order: { createdAt: "DESC" },
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ProductSize | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateProductSizeDto): Promise<ProductSize | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ProductSize)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async findByName(name: string): Promise<ProductSize[] | Error> {
        try {
            return await this.find({
                where: { 
                    name: name, 
                    isDeleted: false 
                }
            });
        }
        catch (e) {
            return e;
        }
    }
}