import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { ProductTagVariantsRepository } from './product-tag-variants.repository';
import { CreateProductTagVariantsDto } from './dto/create-product-tag-variants.dto';
import { UpdateProductTagVariantsDto } from './dto/update-product-tag-variants.dto';
import { ProductTagVariants } from './entities/product-tag-variants.entity';

@Injectable()
export class ProductTagVariantsService {
    constructor(
        @InjectRepository(ProductTagVariantsRepository)
        private readonly repository: ProductTagVariantsRepository
    ) { }

    async create(dto: CreateProductTagVariantsDto): Promise<ProductTagVariants | Error> {
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Product Tag Variants created successfully", "data", data);
    }

    async findAll(): Promise<ProductTagVariants[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product Tag Variants fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateProductTagVariantsDto): Promise<ProductTagVariants | Error> {
        const productTagVariant: any = await this.repository.findOneEntity(id);
        if (!productTagVariant) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product Tag Variants updated successfully", "data", data);
    }

    async findOne(id: string): Promise<ProductTagVariants[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product Tag Variants fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Product Tag Variants deleted successfully");
    }
}
