import { Body, Controller, Delete, Get, Param, Patch, Post, UseGuards } from '@nestjs/common';
import { Constants } from 'src/utils/constants';
import { QuickLinksService } from './quick-links.service';
import { CreateQuickLinksDto } from './dto/create-quick-links.dto';
import { UpdateQuickLinksDto } from './dto/update-quick-links.dto';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';

@Controller({ path: 'quick-links', version: Constants.API_VERSION_1 })

export class QuickLinksController {
    constructor(private readonly service: QuickLinksService) { }

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateQuickLinksDto) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    update(@Param('id') id: string, @Body() dto: UpdateQuickLinksDto) {
        return this.service.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
